@@ -1,7 +1,7 @@
 package Data::Sah::Coerce;
 
-our $DATE = '2018-12-16'; # DATE
-our $VERSION = '0.031'; # VERSION
+our $DATE = '2019-01-21'; # DATE
+our $VERSION = '0.032'; # VERSION
 
 use 5.010001;
 use strict;
@@ -142,7 +142,7 @@ Data::Sah::Coerce - Coercion rules for Data::Sah
 
 =head1 VERSION
 
-This document describes version 0.031 of Data::Sah::Coerce (from Perl distribution Data-Sah-Coerce), released on 2018-12-16.
+This document describes version 0.032 of Data::Sah::Coerce (from Perl distribution Data-Sah-Coerce), released on 2019-01-21.
 
 =head1 SYNOPSIS
 
@@ -185,7 +185,13 @@ the following keys (C<*> marks that the key is required):
 
 =item * v* => int (default: 1)
 
-Metadata specification version. Currently at 3.
+Metadata specification version. Currently at 4.
+
+History: bumped from 3 to 4 to remove C<enable_by_default> property. Now the
+list of standard (enabled-by-default) coercion rules is maintained in
+Data::Sah::Coerce itself. This allows us to skip scanning all
+Data::Sah::Coerce::* coercion modules installed on the system. Data::Sah::Coerce
+still accepts version 3; it just ignores the C<enable_by_default> property.
 
 History: bumped from 2 to 3 to allow coercion expression to return error message
 explaining why coercion fails. The C<might_die> metadata property is replaced
@@ -195,17 +201,6 @@ data.
 
 History: Bumped from 1 to 2 to exclude old module names.
 
-=item * enable_by_default* => bool
-
-Whether the rule should be used by default. Some rules might be useful in
-certain situations only and can set this key's value to 0.
-
-To explicitly enable a disabled-by-default rule or explicitly disable an
-enabled-by-default rule, a Sah schema can set the attribute C<x.coerce_rules> or
-C<x.perl.coerce_rules> to something like C<< ["!str_iso8601", "str_alami"] >>
-(this means to exclude the C<str_iso8601> rule but enable the C<str_alami>
-rule).
-
 =item * might_fail => bool (default: 0)
 
 Whether coercion might fail, e.g. because of invalid input. If set to 1,
@@ -379,7 +374,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
