@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::date::float_epoch;
 
-our $DATE = '2018-12-16'; # DATE
-our $VERSION = '0.031'; # VERSION
+our $DATE = '2019-01-21'; # DATE
+our $VERSION = '0.032'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,8 +9,7 @@ use warnings;
 
 sub meta {
     +{
-        v => 3,
-        enable_by_default => 1,
+        v => 4,
         prio => 50,
         precludes => ['float_epoch_always'],
     };
@@ -63,13 +62,16 @@ Data::Sah::Coerce::perl::date::float_epoch - Coerce date from number (assumed to
 
 =head1 VERSION
 
-This document describes version 0.031 of Data::Sah::Coerce::perl::date::float_epoch (from Perl distribution Data-Sah-Coerce), released on 2018-12-16.
+This document describes version 0.032 of Data::Sah::Coerce::perl::date::float_epoch (from Perl distribution Data-Sah-Coerce), released on 2019-01-21.
 
 =head1 DESCRIPTION
 
-To avoid confusion with number that contains "YYYY", "YYYYMM", or "YYYYMMDD", we
+This rule coerces date from a number that is assumed to be a Unix epoch. To
+avoid confusion with number that contains "YYYY", "YYYYMM", or "YYYYMMDD", we
 only do this coercion if data is a number between 10^8 and 2^31.
 
+Hence, this rule has a Y2038 problem :-).
+
 =for Pod::Coverage ^(meta|coerce)$
 
 =head1 HOMEPAGE
@@ -98,7 +100,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
