@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::date::float_epoch_always;
 
-our $DATE = '2018-12-16'; # DATE
-our $VERSION = '0.031'; # VERSION
+our $DATE = '2019-01-21'; # DATE
+our $VERSION = '0.032'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,8 +9,7 @@ use warnings;
 
 sub meta {
     +{
-        v => 3,
-        enable_by_default => 0,
+        v => 4,
         prio => 50,
         precludes => ['float_epoch', 'str_iso8601'],
     };
@@ -61,10 +60,15 @@ Data::Sah::Coerce::perl::date::float_epoch_always - Coerce date from number (ass
 
 =head1 VERSION
 
-This document describes version 0.031 of Data::Sah::Coerce::perl::date::float_epoch_always (from Perl distribution Data-Sah-Coerce), released on 2018-12-16.
+This document describes version 0.032 of Data::Sah::Coerce::perl::date::float_epoch_always (from Perl distribution Data-Sah-Coerce), released on 2019-01-21.
 
 =head1 DESCRIPTION
 
+This rule coerces date from number (which assumed to be epoch). If data is a
+number and C<coerce_to> is "float(epoch)" (the default), then this rule does
+nothing. If C<coerce_to> is "DateTime" or "Time::Moment" then this rule
+instantiates the appropriate date object using the epoch value.
+
 To avoid confusion with number that contains "YYYY", "YYYYMM", or "YYYYMMDD",
 this coercion rule precludes the
 L<str_iso8601|Data::Sah::Coerce::perl::date::str_iso8601> coercion rule.
@@ -99,7 +103,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
