@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::date::str_iso8601;
 
-our $DATE = '2018-12-16'; # DATE
-our $VERSION = '0.031'; # VERSION
+our $DATE = '2019-01-21'; # DATE
+our $VERSION = '0.032'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,8 +9,7 @@ use warnings;
 
 sub meta {
     +{
-        v => 3,
-        enable_by_default => 1,
+        v => 4,
         might_fail => 1, # we match any (YYYY-MM-DD... string, so the conversion to date might fail on invalid dates)
         prio => 50,
     };
@@ -65,11 +64,12 @@ Data::Sah::Coerce::perl::date::str_iso8601 - Coerce date from (a subset of) ISO8
 
 =head1 VERSION
 
-This document describes version 0.031 of Data::Sah::Coerce::perl::date::str_iso8601 (from Perl distribution Data-Sah-Coerce), released on 2018-12-16.
+This document describes version 0.032 of Data::Sah::Coerce::perl::date::str_iso8601 (from Perl distribution Data-Sah-Coerce), released on 2019-01-21.
 
 =head1 DESCRIPTION
 
-Currently only the following formats are accepted:
+This rule coerces date from a subset of ISO8601 string. Currently only the
+following formats are accepted:
 
  "YYYY-MM-DD"            ; # date (local time), e.g.: 2016-05-13
  "YYYY-MM-DDThh:mm:ss"   ; # date+time (local time), e.g.: 2016-05-13T22:42:00
@@ -102,7 +102,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
